@@ -283,6 +283,124 @@ def is_live_session() -> bool:
     return getpass.getuser() == "ubuntu-studio"
 
 
+# ---------------------------------------------------------------------------
+# FireWire / FFADO support
+# ---------------------------------------------------------------------------
+
+FFADO_PIPEWIRE_CONF_TEMPLATE = """\
+# FireWire (FFADO) audio device configuration for PipeWire
+# Generated by Ubuntu Studio Audio Configuration
+context.objects = [
+    {{ factory = spa-node-factory
+       args = {{
+           factory.name  = api.ffado.device
+           node.name     = "firewire-audio"
+           node.description = "FireWire Audio"
+           node.latency  = {buffer}/{rate}
+           ffado.device  = {device_index}
+       }}
+    }}
+]
+"""
+
+
+@dataclass
+class FFADODevice:
+    """Basic metadata about a connected FireWire audio device."""
+
+    index: int
+    guid: str
+    vendor: str
+    model: str
+
+    @property
+    def display_name(self) -> str:
+        return f"{self.vendor} {self.model} (GUID {self.guid})"
+
+
+def ffado_tools_installed() -> bool:
+    """Return True if the ffado-tools package is installed."""
+    return dpkg_installed("ffado-tools")
+
+
+def firewire_controller_present() -> bool:
+    """Return True if at least one FireWire (IEEE 1394) controller is present."""
+    sysfs = Path("/sys/bus/firewire/devices")
+    if sysfs.exists() and any(sysfs.iterdir()):
+        return True
+    # Fallback: check lspci output
+    res = subprocess.run(["lspci"], capture_output=True, text=True)
+    return bool(re.search(r"firewire|ieee\s?1394", res.stdout, re.IGNORECASE))
+
+
+def list_ffado_devices() -> list[FFADODevice]:
+    """Return a list of FireWire audio devices visible via sysfs.
+
+    Entries in ``/sys/bus/firewire/devices/`` that expose a
+    ``vendor_name`` file are remote nodes (actual devices); entries
+    without that file are the local host controller and are skipped.
+    """
+    devices: list[FFADODevice] = []
+    sysfs = Path("/sys/bus/firewire/devices")
+    if not sysfs.exists():
+        return devices
+    idx = 0
+    for dev_path in sorted(sysfs.iterdir()):
+        vendor_file = dev_path / "vendor_name"
+        model_file = dev_path / "model_name"
+        if not (vendor_file.exists() and model_file.exists()):
+            continue  # local controller — skip
+        guid_file = dev_path / "guid"
+        guid = guid_file.read_text().strip() if guid_file.exists() else "unknown"
+        vendor = vendor_file.read_text().strip()
+        model = model_file.read_text().strip()
+        devices.append(FFADODevice(index=idx, guid=guid, vendor=vendor, model=model))
+        idx += 1
+    return devices
+
+
+def _ffado_conf_path() -> Path:
+    """Return the path for the user-level FFADO PipeWire configuration file."""
+    return (
+        Path.home()
+        / ".config"
+        / "pipewire"
+        / "pipewire.conf.d"
+        / "ubuntustudio-ffado.conf"
+    )
+
+
+def ffado_pw_configured() -> bool:
+    """Return True if a PipeWire FFADO node config file already exists."""
+    return _ffado_conf_path().exists()
+
+
+def write_ffado_pw_config(
+    buffer_size: int,
+    sample_rate: int,
+    device_index: int = 0,
+) -> None:
+    """Write the PipeWire FFADO SPA node config and restart PipeWire."""
+    path = _ffado_conf_path()
+    path.parent.mkdir(parents=True, exist_ok=True)
+    path.write_text(
+        FFADO_PIPEWIRE_CONF_TEMPLATE.format(
+            buffer=buffer_size,
+            rate=sample_rate,
+            device_index=device_index,
+        )
+    )
+    subprocess.run(["systemctl", "--user", "restart", "pipewire"])
+
+
+def remove_ffado_pw_config() -> None:
+    """Remove the PipeWire FFADO node config file and restart PipeWire."""
+    path = _ffado_conf_path()
+    if path.exists():
+        path.unlink()
+    subprocess.run(["systemctl", "--user", "restart", "pipewire"])
+
+
 # ---------------------------------------------------------------------------
 # Dummy audio device
 # ---------------------------------------------------------------------------
