@@ -14,6 +14,7 @@ from PyQt6.QtWidgets import (
     QComboBox,
     QDialog,
     QDialogButtonBox,
+    QFrame,
     QHBoxLayout,
     QInputDialog,
     QLabel,
@@ -62,7 +63,7 @@ def _wrapping_row(button: QCheckBox | QRadioButton, text: str) -> QWidget:
     label.mousePressEvent = lambda _ev: button.toggle()
     row = QWidget()
     h = QHBoxLayout(row)
-    h.setContentsMargins(0, 0, 0, 0)
+    h.setContentsMargins(4, 3, 4, 3)
     h.addWidget(button)
     h.addWidget(label, 1)
     return row
@@ -179,6 +180,8 @@ class QtUI(AudioConfigUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
         info = QLabel(text)
         info.setWordWrap(True)
         layout.addWidget(info)
@@ -226,14 +229,19 @@ class QtUI(AudioConfigUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
         info = QLabel(text)
         info.setWordWrap(True)
         layout.addWidget(info)
 
         scroll = QScrollArea()
         scroll.setWidgetResizable(True)
+        scroll.setFrameShape(QFrame.Shape.NoFrame)
         container = QWidget()
         vbox = QVBoxLayout(container)
+        vbox.setSpacing(2)
+        vbox.setContentsMargins(4, 4, 4, 4)
 
         checks: list[tuple[str, QCheckBox]] = []
         for item in items:
@@ -277,14 +285,19 @@ class QtUI(AudioConfigUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
         info = QLabel(text)
         info.setWordWrap(True)
         layout.addWidget(info)
 
         scroll = QScrollArea()
         scroll.setWidgetResizable(True)
+        scroll.setFrameShape(QFrame.Shape.NoFrame)
         container = QWidget()
         vbox = QVBoxLayout(container)
+        vbox.setSpacing(2)
+        vbox.setContentsMargins(4, 4, 4, 4)
 
         group = QButtonGroup(dlg)
         radios: list[tuple[str, QRadioButton]] = []
@@ -334,6 +347,8 @@ class QtUI(AudioConfigUI):
         dlg.setMinimumWidth(500)
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
 
         label = QLabel(text)
         label.setWordWrap(True)
